@@ -2,7 +2,7 @@
 /**
  * Kronolith external API interface.
  *
- * $Horde: kronolith/lib/api.php,v 1.126.2.53 2008/08/18 22:40:33 jan Exp $
+ * $Horde: kronolith/lib/api.php,v 1.126.2.64 2009/09/04 10:38:36 jan Exp $
  *
  * This file defines Kronolith's external API interface. Other applications
  * can interact with Kronolith through this API.
@@ -10,6 +10,11 @@
  * @package Kronolith
  */
 
+$_services['show'] = array(
+    'link' => '%application%/event.php?calendar=|calendar|' .
+              '&eventID=|event|&uid=|uid|'
+);
+
 $_services['perms'] = array(
     'args' => array(),
     'type' => '{urn:horde}stringArray'
@@ -24,13 +29,13 @@ $_services['shareHelp'] = array(
     'args' => array(),
     'type' => 'string');
 
-$_services['show'] = array(
-    'link' => '%application%/event.php?calendar=|calendar|' .
-              '&eventID=|event|&uid=|uid|'
+$_services['modified'] = array(
+    'args' => array('uid' => 'string'),
+    'type' => 'int',
 );
 
 $_services['browse'] = array(
-    'args' => array('path' => 'string'),
+    'args' => array('path' => 'string', 'properties' => '{urn:horde}stringArray'),
     'type' => '{urn:horde}hashHash',
 );
 
@@ -70,18 +75,18 @@ $_services['list'] = array(
 );
 
 $_services['listBy'] = array(
-    'args' => array('action' => 'string', 'timestamp' => 'int'),
+    'args' => array('action' => 'string', 'timestamp' => 'int', 'calendar' => 'string'),
     'type' => '{urn:horde}stringArray'
 );
 
 $_services['getActionTimestamp'] = array(
-    'args' => array('uid' => 'string', 'timestamp' => 'int'),
+    'args' => array('uid' => 'string', 'action' => 'string', 'calendar' => 'string'),
     'type' => 'int',
 );
 
 $_services['import'] = array(
     'args' => array('content' => 'string', 'contentType' => 'string', 'calendar' => 'string'),
-    'type' => 'int'
+    'type' => 'string'
 );
 
 $_services['export'] = array(
@@ -222,7 +227,7 @@ function _kronolith_shareHelp()
  *
  * @return integer  The timestamp for the last modification of $uid.
  */
-function __kronolith_modified($uid)
+function _kronolith_modified($uid)
 {
     $modified = _kronolith_getActionTimestamp($uid, 'modify');
     if (empty($modified)) {
@@ -257,6 +262,11 @@ function _kronolith_browse($path = '', $properties = array())
     $parts = explode('/', $path);
 
     if (empty($path)) {
+        //
+        // This request is for a list of all users who have calendars visible
+        // to the requesting user.
+        //
+        $calendars = Kronolith::listCalendars(false, PERMS_READ);
         $owners = array();
         foreach ($calendars as $calendar) {
             $owners[$calendar->get('owner')] = true;
@@ -385,7 +395,7 @@ function _kronolith_browse($path = '', $properties = array())
                 $results[$key]['contentlength'] = 1;
             }
             if (in_array('modified', $properties)) {
-                $results[$key]['modified'] = __kronolith_modified($uid);
+                $results[$key]['modified'] = _kronolith_modified($uid);
             }
             if (in_array('created', $properties)) {
                 $results[$key]['created'] = _kronolith_getActionTimestamp($uid, 'add');
@@ -415,7 +425,7 @@ function _kronolith_browse($path = '', $properties = array())
             $result = array(
                 'data' => _kronolith_export($event->getUID(), 'text/calendar'),
                 'mimetype' => 'text/calendar');
-            $modified = __kronolith_modified($event->getUID());
+            $modified = _kronolith_modified($event->getUID());
             if (!empty($modified)) {
                 $result['mtime'] = $modified;
             }
@@ -831,7 +841,6 @@ function _kronolith_import($content, $contentType, $calendar = null)
     }
 
     return PEAR::raiseError(sprintf(_("Unsupported Content-Type: %s"), $contentType));
-
 }
 
 /**
@@ -882,7 +891,6 @@ function _kronolith_export($uid, $contentType)
     }
 
     return PEAR::raiseError(sprintf(_("Unsupported Content-Type: %s"), $contentType));;
-
 }
 
 /**
@@ -940,7 +948,6 @@ function _kronolith_exportCalendar($calendar, $contentType)
     }
 
     return PEAR::raiseError(sprintf(_("Unsupported Content-Type: %s"), $contentType));
-
 }
 
 /**
@@ -953,8 +960,8 @@ function _kronolith_exportCalendar($calendar, $contentType)
  */
 function _kronolith_delete($uid)
 {
-    /* Handle an array of UIDs for convenience of deleting multiple events at
-     * once. */
+    // Handle an array of UIDs for convenience of deleting multiple events at
+    // once.
     if (is_array($uid)) {
         foreach ($uid as $g) {
             $result = _kronolith_delete($g);
@@ -979,7 +986,7 @@ function _kronolith_delete($uid)
         $event = $events[0];
     }
 
-    /* First try the user's own calendars. */
+    // First try the user's own calendars.
     if (empty($event)) {
         $ownerCalendars = Kronolith::listCalendars(true, PERMS_DELETE);
         foreach ($events as $ev) {
@@ -990,7 +997,7 @@ function _kronolith_delete($uid)
         }
     }
 
-    /* If not successful, try all calendars the user has access too. */
+    // If not successful, try all calendars the user has access to.
     if (empty($event)) {
         $deletableCalendars = Kronolith::listCalendars(false, PERMS_DELETE);
         foreach ($events as $ev) {
@@ -1073,8 +1080,8 @@ function _kronolith_replace($uid, $content, $contentType)
     }
 
     $event->fromiCalendar($component);
-    /* Ensure we keep the original UID, even when content does not
-     * contain one and fromiCalendar creates a new one. */
+    // Ensure we keep the original UID, even when content does not
+    // contain one and fromiCalendar creates a new one.
     $event->setUID($uid);
     $eventId = $event->save();
 
