@@ -1,6 +1,6 @@
 <?php
 /**
- * $Horde: kronolith/perms.php,v 1.5.2.6 2009/01/06 15:24:43 jan Exp $
+ * $Horde: kronolith/perms.php,v 1.5.2.7 2009/09/11 13:09:39 jan Exp $
  *
  * Copyright 2002-2009 The Horde Project (http://www.horde.org/)
  *
@@ -55,6 +55,8 @@ case 'editform':
         if ($old_owner !== $new_owner && !empty($new_owner)) {
             if ($old_owner != Auth::getAuth() && !Auth::isAdmin()) {
                 $notification->push(_("Only the owner or system administrator may change ownership or owner permissions for a share"), 'horde.error');
+            } elseif ($auth->hasCapability('list') && !$auth->exists($new_owner)) {
+                $notification->push(sprintf(_("The user \"%s\" does not exist."), Auth::removeHook($new_owner)), 'horde.error');
             } else {
                 $share->set('owner', $new_owner);
                 $share->save();
@@ -158,6 +160,10 @@ case 'editform':
             if (empty($user) || $user == $new_owner) {
                 continue;
             }
+            if ($auth->hasCapability('list') && !$auth->exists($user)) {
+                $notification->push(sprintf(_("The user \"%s\" does not exist."), Auth::removeHook($user)), 'horde.error');
+                continue;
+            }
 
             if (!empty($u_show[$key])) {
                 $perm->addUserPermission($user, PERMS_SHOW, false);
